@@ -30,12 +30,6 @@ class Command(BaseCommand):
             action="store_true",
             default=settings.is_pytest,
         )
-        parser.add_argument(
-            "--directory",
-            dest="location",
-            default=settings.location,
-            help="Deprecated, use --location instead.",
-        )
         parser.add_argument("--location", default=settings.location)
         parser.add_argument(
             "--storage",
@@ -44,6 +38,7 @@ class Command(BaseCommand):
             type=get_storage_class,
         )
         parser.add_argument("--depth", type=int, default=settings.depth)
+        parser.add_argument("--reuse-db", action="store_true", default=False)
 
     def _setup_logging(self):
         lib_logger = logging.getLogger("django_migrations_ci")
@@ -59,6 +54,7 @@ class Command(BaseCommand):
         storage_class,
         depth,
         verbosity,
+        reuse_db,
         **options,
     ):
         self._setup_logging()
@@ -100,7 +96,7 @@ class Command(BaseCommand):
                     logger.info(f"Migrations current checksum is {current_checksum}.")
 
             cached_files = {
-                connection.alias: f"migrateci-{connection.alias}-{cached_checksum}"
+                connection.alias: _migration_filename(connection, cached_checksum)
                 for connection in unique_connections
             }
             if all(f in files for f in cached_files.values()):
@@ -129,11 +125,18 @@ class Command(BaseCommand):
         if cached_files:
             if verbosity >= 2:
                 logger.info(f"Create test db from cache {cached_checksum=}.")
-            django.create_test_db(verbosity=verbosity)
             for connection in unique_connections:
-                cached_file = cached_files[connection.alias]
-                with django.test_db(connection):
-                    django.load(connection, cached_file, storage, verbosity=verbosity)
+                database_name, db_created = django.create_test_db(
+                    connection, verbosity=verbosity, keepdb=reuse_db
+                )
+                if db_created or not reuse_db:
+                    cached_file = cached_files[connection.alias]
+                    with django.test_db(connection):
+                        django.load(
+                            connection, cached_file, storage, verbosity=verbosity
+                        )
+                elif verbosity >= 2:
+                    logger.info(f"Reusing database {database_name}.")
 
         if current_checksum != cached_checksum:
             if verbosity >= 2:
@@ -143,7 +146,7 @@ class Command(BaseCommand):
 
             django.setup_test_db(verbosity=verbosity)
             for connection in unique_connections:
-                current_file = f"migrateci-{connection.alias}-{current_checksum}"
+                current_file = _migration_filename(connection, current_checksum)
                 with django.test_db(connection):
                     django.dump(connection, current_file, storage, verbosity=verbosity)
 
@@ -158,3 +161,7 @@ class Command(BaseCommand):
                         is_pytest=is_pytest,
                         verbosity=verbosity,
                     )
+
+
+def _migration_filename(connection, checksum):
+    return f"migrateci-{connection.vendor}-{connection.alias}-{checksum}"
\ No newline at end of file
